# RequestSettingsAdditional


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**action** | **str, none_type** | Allows you to terminate request handling and immediately perform an action. | [optional] 
**default_host** | **str, none_type** | Sets the host header. | [optional] 
**hash_keys** | **str, none_type** | Comma separated list of varnish request object fields that should be in the hash key. | [optional] 
**name** | **str** | Name for the request settings. | [optional] 
**request_condition** | **str, none_type** | Condition which, if met, will select this configuration during a request. Optional. | [optional] 
**xff** | **str** | Short for X-Forwarded-For. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


